/*
 * Copyright (C) 1999-2015. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.17.0 2015-04-20
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef DIFF_SOURCE
#define DIFF_SOURCE

#include "../../constant/model/cyboi/log/level_log_cyboi_model.c"
#include "../../constant/model/cyboi/log/message_log_cyboi_model.c"
#include "../../constant/model/cyboi/state/integer_state_cyboi_model.c"
#include "../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
#include "../../constant/name/cybol/logic/commander/diff_commander_logic_cybol_name.c"
#include "../../constant/type/cyboi/state_cyboi_type.c"
#include "../../executor/accessor/getter/part/name_part_getter.c"
#include "../../executor/commander/diff_commander.c"
#include "../../logger/logger.c"

#ifndef _MSC_VER
#include <unistd.h>
#endif

/**
* Compares two files
*
* Expected parametres:
* - first file (required): first file to compare
* - second file (required): second file to compare
*
* Constraints:
*
* @param p0 the parametres data
* @param p1 the parametres count
* @param p2 the knowledge memory part
*/
void apply_diff(void* p0, void* p1, void* p2) {

    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Apply grep.");

    // The first file part.
    void* f1 = *NULL_POINTER_STATE_CYBOI_MODEL;
    // The second file part.
    void* f2 = *NULL_POINTER_STATE_CYBOI_MODEL;

    // The first file part model item.
    void* f1m = *NULL_POINTER_STATE_CYBOI_MODEL;
    // The second file part model item.
    void* f2m = *NULL_POINTER_STATE_CYBOI_MODEL;

    // The first file part model item data and count.
    void* f1md = *NULL_POINTER_STATE_CYBOI_MODEL;
    void* f1mc = *NULL_POINTER_STATE_CYBOI_MODEL;
    // The second file part model item data and count.
    void* f2md = *NULL_POINTER_STATE_CYBOI_MODEL;
    void* f2mc = *NULL_POINTER_STATE_CYBOI_MODEL;

    // Get first file part.
    get_part_name((void*) &f1, p0, (void*) FILE1_DIFF_FILE_COMMANDER_LOGIC_CYBOL_NAME, (void*) FILE1_DIFF_FILE_COMMANDER_LOGIC_CYBOL_NAME_COUNT, p1, p2);
    // Get second file part.
    get_part_name((void*) &f2, p0, (void*) FILE2_DIFF_FILE_COMMANDER_LOGIC_CYBOL_NAME, (void*) FILE2_DIFF_FILE_COMMANDER_LOGIC_CYBOL_NAME_COUNT, p1, p2);

    // Get first file part model item.
    copy_array_forward((void*) &f1m, f1, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);
    // Get second file part model item.
    copy_array_forward((void*) &f2m, f2, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);

    // Get first file part model item data and count.
    copy_array_forward((void*) &f1md, f1m, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
    copy_array_forward((void*) &f1mc, f1m, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);
    // Get second file part model item data and count.
    copy_array_forward((void*) &f2md, f2m, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) DATA_ITEM_STATE_CYBOI_NAME);
    copy_array_forward((void*) &f2mc, f2m, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) COUNT_ITEM_STATE_CYBOI_NAME);

    command_diff(f1md, f1mc, f2md, f2mc);
}

/* GREP_SOURCE */
#endif
