/*
 * Copyright (C) 1999-2015. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.17.0 2015-04-20
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef INTERNAL_MEMORY_STATE_CYBOI_NAME_CONSTANT_SOURCE
#define INTERNAL_MEMORY_STATE_CYBOI_NAME_CONSTANT_SOURCE

#include "../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

//
// These constants are NOT sorted alphabetically, but as follows:
// - knowledge memory
// - signal memory
// - serial port
// - terminal
// - display
// - socket
//
// CAUTION! The socket stands at last, since unpredictably
// many socket services may have to be added in the future.
//

/** The knowledge memory. */
static int* KNOWLEDGE_MEMORY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_0_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The signal memory. */
static int* SIGNAL_MEMORY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_10_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* SLEEP_TIME_SIGNAL_MEMORY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_11_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/**
 * The serial port.
 *
 * The total number of possible socket services (ports) is: 1
 */
static int* SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_100_INTEGER_STATE_CYBOI_MODEL_ARRAY;

//?? TODO: The following constants are OUTDATED and may be deleted in the future.
/** The serial port. */
static int* ENABLE_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_110_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* INTERRUPT_REQUEST_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_111_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* HANDLER_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_112_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* MUTEX_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_113_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* SLEEP_TIME_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_114_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* FILE_DESCRIPTOR_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_115_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* ORIGINAL_ATTRIBUTES_SERIAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_116_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/**
 * The terminal.
 *
 * The total number of possible socket services (ports) is: 1
 */
static int* TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_200_INTEGER_STATE_CYBOI_MODEL_ARRAY;

//?? TODO: The following constants are OUTDATED and may be deleted in the future.
/** The terminal. */
static int* ENABLE_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_210_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* INTERRUPT_REQUEST_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_211_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* HANDLER_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_212_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* MUTEX_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_213_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* SLEEP_TIME_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_214_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* INPUT_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_215_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* OUTPUT_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_216_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* ORIGINAL_ATTRIBUTES_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_217_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* INPUT_MODE_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_218_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* OUTPUT_MODE_TERMINAL_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_219_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/**
 * The display.
 *
 * The total number of possible socket services (ports) is: 1
 */
static int* DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_300_INTEGER_STATE_CYBOI_MODEL_ARRAY;

//?? TODO: The following constants are OUTDATED and may be deleted in the future.
/** The display. */
static int* ENABLE_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_310_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* INTERRUPT_REQUEST_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_311_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* HANDLER_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_312_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* MUTEX_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_313_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* SLEEP_TIME_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_314_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* EVENT_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_315_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* CONNEXION_XCB_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_316_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* SCREEN_XCB_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_317_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* WINDOW_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_318_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* GRAPHIC_CONTEXT_XCB_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_319_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* FONT_XCB_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_320_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* DEVICE_CONTEXT_WIN32_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_321_INTEGER_STATE_CYBOI_MODEL_ARRAY;
static int* COLOUR_MAP_XCB_DISPLAY_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_322_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/**
 * The socket base.
 *
 * The PORT NUMBER is used as offset to this base number,
 * so that each network service has its own memory space.
 *
 * CAUTION! Only SERVER SOCKETS are stored here.
 * If this CYBOI interpreter acts as client asking
 * another service, then that socket number has to be
 * stored in the corresponding CYBOL application.
 *
 * The total number of possible socket services (ports) is: 65536
 */
static int* SOCKET_INTERNAL_MEMORY_STATE_CYBOI_NAME = NUMBER_400_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* INTERNAL_MEMORY_STATE_CYBOI_NAME_CONSTANT_SOURCE */
#endif
