/*
 * Copyright (C) 1999-2015. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.17.0 2015-04-20
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef PART_EMPTIER_SOURCE
#define PART_EMPTIER_SOURCE

#include "../../../constant/model/cyboi/log/level_log_cyboi_model.c"
#include "../../../constant/model/cyboi/log/message_log_cyboi_model.c"
#include "../../../constant/model/cyboi/state/pointer_state_cyboi_model.c"
#include "../../../constant/model/cyboi/state/state_cyboi_model.c"
#include "../../../constant/name/cyboi/state/item_state_cyboi_name.c"
#include "../../../constant/name/cyboi/state/primitive_state_cyboi_name.c"
#include "../../../constant/type/cyboi/state_cyboi_type.c"
#include "../../../executor/modifier/emptier/item_emptier.c"
#include "../../../logger/logger.c"

/**
 * Empties the part.
 *
 * The name, type and properties of the part remain unchanged.
 * Only the model gets touched by removing all of its elements.
 *
 * The count and size are adjusted automatically.
 *
 * @param p0 the part
 * @param p1 the type
 * @param p2 the model flag
 * @param p3 the properties flag
 */
void empty_part(void* p0, void* p1, void* p2, void* p3) {

    log_message_terminated((void*) INFORMATION_LEVEL_LOG_CYBOI_MODEL, (void*) L"Empty part.");

    // The part model, properties.
    void* m = *NULL_POINTER_STATE_CYBOI_MODEL;
    void* p = *NULL_POINTER_STATE_CYBOI_MODEL;

    // Get part model, properties.
    copy_array_forward((void*) &m, p0, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) MODEL_PART_STATE_CYBOI_NAME);
    copy_array_forward((void*) &p, p0, (void*) POINTER_STATE_CYBOI_TYPE, (void*) PRIMITIVE_STATE_CYBOI_MODEL_COUNT, (void*) VALUE_PRIMITIVE_STATE_CYBOI_NAME, (void*) PROPERTIES_PART_STATE_CYBOI_NAME);

    if (p2 != *NULL_POINTER_STATE_CYBOI_MODEL) {

        int* mf = (int*) p2;

        if (*mf != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {

            // Empty part model.
            empty_item(m, p1);
        }
    }

    if (p3 != *NULL_POINTER_STATE_CYBOI_MODEL) {

        int* pf = (int*) p3;

        if (*pf != *FALSE_BOOLEAN_STATE_CYBOI_MODEL) {

            // Empty part properties.
            empty_item(p, (void*) PART_ELEMENT_STATE_CYBOI_TYPE);
        }
    }
}

/* PART_EMPTIER_SOURCE */
#endif
